diff --git a/mobile/android_test.go b/mobile/android_test.go
index 9e38c198656691ebd9a11ecea4d10158b26505c6..3776f829118eb21572f86bbbe919403f90b8a835 100644
--- a/mobile/android_test.go
+++ b/mobile/android_test.go
@@ -69,7 +69,7 @@ public class AndroidTest extends InstrumentationTestCase {
 			Hash txHash = new Hash("0x0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef");
 
 			// Sign a transaction with a single authorization
-			byte[] signature = am.signWithPassphrase(signer, "Signer password", txHash.getBytes());
+			byte[] signature = am.signPassphrase(signer, "Signer password", txHash.getBytes());
 
 			// Sign a transaction with multiple manually cancelled authorizations
 			am.unlock(signer, "Signer password");
diff --git a/mobile/accounts.go b/mobile/accounts.go
index 90f664d291caac0191b80d634dc1a1215610188a..47c3a5c211894a59ffff7125bf927c2620e8c77b 100644
--- a/mobile/accounts.go
+++ b/mobile/accounts.go
@@ -115,10 +115,10 @@ func (am *AccountManager) Sign(address *Address, hash []byte) (signature []byte,
 	return am.manager.Sign(address.address, hash)
 }
 
 // SignWithPassphrase signs hash if the private key matching the given address
 // can be decrypted with the given passphrase. The produced signature is in the
 // [R || S || V] format where V is 0 or 1.
-func (am *AccountManager) SignWithPassphrase(account *Account, passphrase string, hash []byte) (signature []byte, _ error) {
+func (am *AccountManager) SignPassphrase(account *Account, passphrase string, hash []byte) (signature []byte, _ error) {
 	return am.manager.SignWithPassphrase(account.account, passphrase, hash)
 }
 
@@ -115,10 +115,10 @@ func (am *AccountManager) Sign(address *Address, hash []byte) (signature []byte,
 }
 
-// SignWithPassphrase signs hash if the private key matching the given address
-// can be decrypted with the given passphrase. The produced signature is in the
+// SignPassphrase signs hash if the private key matching the given address can
+// be decrypted with the given passphrase. The produced signature is in the
 // [R || S || V] format where V is 0 or 1.